/* This file was automatically created by ./mktables */
#define SL_TOUPPER_MAX_CHAR 0x1E980ul

#define SL_TOUPPER_LOOKUP(x) \
  (((unsigned)(x)>=SL_TOUPPER_MAX_CHAR)?0:(_pSLwc_Toupper_Table[(unsigned)(x)>>7][(unsigned)(x)&0x7F]))

extern const _pSLint32_Type *_pSLwc_Toupper_Table[979];

#ifdef DEFINE_PSLWC_TOUPPER_TABLE
static const _pSLint32_Type Table_00[128] =
{
  /*0x00-0x07*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x08-0x0F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x10-0x17*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x18-0x1F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x20-0x27*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x28-0x2F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x30-0x37*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x38-0x3F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x40-0x47*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x48-0x4F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x50-0x57*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x58-0x5F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x60-0x67*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x68-0x6F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x70-0x77*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x78-0x7F*/     0,     0,     0,     0,     0,     0,     0,     0
};

static const _pSLint32_Type Table_01[128] =
{
  /*0x00-0x07*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x08-0x0F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x10-0x17*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x18-0x1F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x20-0x27*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x28-0x2F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x30-0x37*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x38-0x3F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x40-0x47*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x48-0x4F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x50-0x57*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x58-0x5F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x60-0x67*/     0,   -32,   -32,   -32,   -32,   -32,   -32,   -32,
  /*0x68-0x6F*/   -32,   -32,   -32,   -32,   -32,   -32,   -32,   -32,
  /*0x70-0x77*/   -32,   -32,   -32,   -32,   -32,   -32,   -32,   -32,
  /*0x78-0x7F*/   -32,   -32,   -32,     0,     0,     0,     0,     0
};

static const _pSLint32_Type Table_02[128] =
{
  /*0x00-0x07*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x08-0x0F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x10-0x17*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x18-0x1F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x20-0x27*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x28-0x2F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x30-0x37*/     0,     0,     0,     0,     0,   743,     0,     0,
  /*0x38-0x3F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x40-0x47*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x48-0x4F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x50-0x57*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x58-0x5F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x60-0x67*/   -32,   -32,   -32,   -32,   -32,   -32,   -32,   -32,
  /*0x68-0x6F*/   -32,   -32,   -32,   -32,   -32,   -32,   -32,   -32,
  /*0x70-0x77*/   -32,   -32,   -32,   -32,   -32,   -32,   -32,     0,
  /*0x78-0x7F*/   -32,   -32,   -32,   -32,   -32,   -32,   -32,   121
};

static const _pSLint32_Type Table_03[128] =
{
  /*0x00-0x07*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x08-0x0F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x10-0x17*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x18-0x1F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x20-0x27*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x28-0x2F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x30-0x37*/     0,  -232,     0,    -1,     0,    -1,     0,    -1,
  /*0x38-0x3F*/     0,     0,    -1,     0,    -1,     0,    -1,     0,
  /*0x40-0x47*/    -1,     0,    -1,     0,    -1,     0,    -1,     0,
  /*0x48-0x4F*/    -1,     0,     0,    -1,     0,    -1,     0,    -1,
  /*0x50-0x57*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x58-0x5F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x60-0x67*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x68-0x6F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x70-0x77*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x78-0x7F*/     0,     0,    -1,     0,    -1,     0,    -1,  -300
};

static const _pSLint32_Type Table_04[128] =
{
  /*0x00-0x07*/   195,     0,     0,    -1,     0,    -1,     0,     0,
  /*0x08-0x0F*/    -1,     0,     0,     0,    -1,     0,     0,     0,
  /*0x10-0x17*/     0,     0,    -1,     0,     0,    97,     0,     0,
  /*0x18-0x1F*/     0,    -1,   163,     0,     0,     0,   130,     0,
  /*0x20-0x27*/     0,    -1,     0,    -1,     0,    -1,     0,     0,
  /*0x28-0x2F*/    -1,     0,     0,     0,     0,    -1,     0,     0,
  /*0x30-0x37*/    -1,     0,     0,     0,    -1,     0,    -1,     0,
  /*0x38-0x3F*/     0,    -1,     0,     0,     0,    -1,     0,    56,
  /*0x40-0x47*/     0,     0,     0,     0,     0,    -1,    -2,     0,
  /*0x48-0x4F*/    -1,    -2,     0,    -1,    -2,     0,    -1,     0,
  /*0x50-0x57*/    -1,     0,    -1,     0,    -1,     0,    -1,     0,
  /*0x58-0x5F*/    -1,     0,    -1,     0,    -1,   -79,     0,    -1,
  /*0x60-0x67*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x68-0x6F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x70-0x77*/     0,     0,    -1,    -2,     0,    -1,     0,     0,
  /*0x78-0x7F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1
};

static const _pSLint32_Type Table_05[128] =
{
  /*0x00-0x07*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x08-0x0F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x10-0x17*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x18-0x1F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x20-0x27*/     0,     0,     0,    -1,     0,    -1,     0,    -1,
  /*0x28-0x2F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x30-0x37*/     0,    -1,     0,    -1,     0,     0,     0,     0,
  /*0x38-0x3F*/     0,     0,     0,     0,    -1,     0,     0,  10815,
  /*0x40-0x47*/  10815,     0,    -1,     0,     0,     0,     0,    -1,
  /*0x48-0x4F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x50-0x57*/  10783,  10780,  10782,  -210,  -206,     0,  -205,  -205,
  /*0x58-0x5F*/     0,  -202,     0,  -203,  42319,     0,     0,     0,
  /*0x60-0x67*/  -205,  42315,     0,  -207,     0,  42280,  42308,     0,
  /*0x68-0x6F*/  -209,  -211,  42308,  10743,  42305,     0,     0,  -211,
  /*0x70-0x77*/     0,  10749,  -213,     0,     0,  -214,     0,     0,
  /*0x78-0x7F*/     0,     0,     0,     0,     0,  10727,     0,     0
};

static const _pSLint32_Type Table_06[128] =
{
  /*0x00-0x07*/  -218,     0,     0,  -218,     0,     0,     0,  42282,
  /*0x08-0x0F*/  -218,   -69,  -217,  -217,   -71,     0,     0,     0,
  /*0x10-0x17*/     0,     0,  -219,     0,     0,     0,     0,     0,
  /*0x18-0x1F*/     0,     0,     0,     0,     0,  42261,  42258,     0,
  /*0x20-0x27*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x28-0x2F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x30-0x37*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x38-0x3F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x40-0x47*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x48-0x4F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x50-0x57*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x58-0x5F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x60-0x67*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x68-0x6F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x70-0x77*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x78-0x7F*/     0,     0,     0,     0,     0,     0,     0,     0
};

static const _pSLint32_Type Table_07[128] =
{
  /*0x00-0x07*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x08-0x0F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x10-0x17*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x18-0x1F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x20-0x27*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x28-0x2F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x30-0x37*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x38-0x3F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x40-0x47*/     0,     0,     0,     0,     0,    84,     0,     0,
  /*0x48-0x4F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x50-0x57*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x58-0x5F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x60-0x67*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x68-0x6F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x70-0x77*/     0,    -1,     0,    -1,     0,     0,     0,    -1,
  /*0x78-0x7F*/     0,     0,     0,   130,   130,   130,     0,     0
};

static const _pSLint32_Type Table_08[128] =
{
  /*0x00-0x07*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x08-0x0F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x10-0x17*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x18-0x1F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x20-0x27*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x28-0x2F*/     0,     0,     0,     0,   -38,   -37,   -37,   -37,
  /*0x30-0x37*/     0,   -32,   -32,   -32,   -32,   -32,   -32,   -32,
  /*0x38-0x3F*/   -32,   -32,   -32,   -32,   -32,   -32,   -32,   -32,
  /*0x40-0x47*/   -32,   -32,   -31,   -32,   -32,   -32,   -32,   -32,
  /*0x48-0x4F*/   -32,   -32,   -32,   -32,   -64,   -63,   -63,     0,
  /*0x50-0x57*/   -62,   -57,     0,     0,     0,   -47,   -54,    -8,
  /*0x58-0x5F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x60-0x67*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x68-0x6F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x70-0x77*/   -86,   -80,     7,  -116,     0,   -96,     0,     0,
  /*0x78-0x7F*/    -1,     0,     0,    -1,     0,     0,     0,     0
};

static const _pSLint32_Type Table_09[128] =
{
  /*0x00-0x07*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x08-0x0F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x10-0x17*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x18-0x1F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x20-0x27*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x28-0x2F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x30-0x37*/   -32,   -32,   -32,   -32,   -32,   -32,   -32,   -32,
  /*0x38-0x3F*/   -32,   -32,   -32,   -32,   -32,   -32,   -32,   -32,
  /*0x40-0x47*/   -32,   -32,   -32,   -32,   -32,   -32,   -32,   -32,
  /*0x48-0x4F*/   -32,   -32,   -32,   -32,   -32,   -32,   -32,   -32,
  /*0x50-0x57*/   -80,   -80,   -80,   -80,   -80,   -80,   -80,   -80,
  /*0x58-0x5F*/   -80,   -80,   -80,   -80,   -80,   -80,   -80,   -80,
  /*0x60-0x67*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x68-0x6F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x70-0x77*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x78-0x7F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1
};

static const _pSLint32_Type Table_10[128] =
{
  /*0x00-0x07*/     0,    -1,     0,     0,     0,     0,     0,     0,
  /*0x08-0x0F*/     0,     0,     0,    -1,     0,    -1,     0,    -1,
  /*0x10-0x17*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x18-0x1F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x20-0x27*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x28-0x2F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x30-0x37*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x38-0x3F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x40-0x47*/     0,     0,    -1,     0,    -1,     0,    -1,     0,
  /*0x48-0x4F*/    -1,     0,    -1,     0,    -1,     0,    -1,   -15,
  /*0x50-0x57*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x58-0x5F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x60-0x67*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x68-0x6F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x70-0x77*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x78-0x7F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1
};

static const _pSLint32_Type Table_11[128] =
{
  /*0x00-0x07*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x08-0x0F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x10-0x17*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x18-0x1F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x20-0x27*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x28-0x2F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x30-0x37*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x38-0x3F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x40-0x47*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x48-0x4F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x50-0x57*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x58-0x5F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x60-0x67*/     0,   -48,   -48,   -48,   -48,   -48,   -48,   -48,
  /*0x68-0x6F*/   -48,   -48,   -48,   -48,   -48,   -48,   -48,   -48,
  /*0x70-0x77*/   -48,   -48,   -48,   -48,   -48,   -48,   -48,   -48,
  /*0x78-0x7F*/   -48,   -48,   -48,   -48,   -48,   -48,   -48,   -48
};

static const _pSLint32_Type Table_12[128] =
{
  /*0x00-0x07*/   -48,   -48,   -48,   -48,   -48,   -48,   -48,     0,
  /*0x08-0x0F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x10-0x17*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x18-0x1F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x20-0x27*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x28-0x2F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x30-0x37*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x38-0x3F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x40-0x47*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x48-0x4F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x50-0x57*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x58-0x5F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x60-0x67*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x68-0x6F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x70-0x77*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x78-0x7F*/     0,     0,     0,     0,     0,     0,     0,     0
};

static const _pSLint32_Type Table_13[128] =
{
  /*0x00-0x07*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x08-0x0F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x10-0x17*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x18-0x1F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x20-0x27*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x28-0x2F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x30-0x37*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x38-0x3F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x40-0x47*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x48-0x4F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x50-0x57*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x58-0x5F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x60-0x67*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x68-0x6F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x70-0x77*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x78-0x7F*/    -8,    -8,    -8,    -8,    -8,    -8,     0,     0
};

static const _pSLint32_Type Table_14[128] =
{
  /*0x00-0x07*/ -6254, -6253, -6244, -6242, -6242, -6243, -6236, -6181,
  /*0x08-0x0F*/  35266,     0,     0,     0,     0,     0,     0,     0,
  /*0x10-0x17*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x18-0x1F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x20-0x27*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x28-0x2F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x30-0x37*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x38-0x3F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x40-0x47*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x48-0x4F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x50-0x57*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x58-0x5F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x60-0x67*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x68-0x6F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x70-0x77*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x78-0x7F*/     0,     0,     0,     0,     0,     0,     0,     0
};

static const _pSLint32_Type Table_15[128] =
{
  /*0x00-0x07*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x08-0x0F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x10-0x17*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x18-0x1F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x20-0x27*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x28-0x2F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x30-0x37*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x38-0x3F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x40-0x47*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x48-0x4F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x50-0x57*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x58-0x5F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x60-0x67*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x68-0x6F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x70-0x77*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x78-0x7F*/     0,  35332,     0,     0,     0,  3814,     0,     0
};

static const _pSLint32_Type Table_16[128] =
{
  /*0x00-0x07*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x08-0x0F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x10-0x17*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x18-0x1F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x20-0x27*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x28-0x2F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x30-0x37*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x38-0x3F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x40-0x47*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x48-0x4F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x50-0x57*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x58-0x5F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x60-0x67*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x68-0x6F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x70-0x77*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x78-0x7F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1
};

static const _pSLint32_Type Table_17[128] =
{
  /*0x00-0x07*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x08-0x0F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x10-0x17*/     0,    -1,     0,    -1,     0,    -1,     0,     0,
  /*0x18-0x1F*/     0,     0,     0,   -59,     0,     0,     0,     0,
  /*0x20-0x27*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x28-0x2F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x30-0x37*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x38-0x3F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x40-0x47*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x48-0x4F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x50-0x57*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x58-0x5F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x60-0x67*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x68-0x6F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x70-0x77*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x78-0x7F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1
};

static const _pSLint32_Type Table_18[128] =
{
  /*0x00-0x07*/     8,     8,     8,     8,     8,     8,     8,     8,
  /*0x08-0x0F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x10-0x17*/     8,     8,     8,     8,     8,     8,     0,     0,
  /*0x18-0x1F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x20-0x27*/     8,     8,     8,     8,     8,     8,     8,     8,
  /*0x28-0x2F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x30-0x37*/     8,     8,     8,     8,     8,     8,     8,     8,
  /*0x38-0x3F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x40-0x47*/     8,     8,     8,     8,     8,     8,     0,     0,
  /*0x48-0x4F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x50-0x57*/     0,     8,     0,     8,     0,     8,     0,     8,
  /*0x58-0x5F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x60-0x67*/     8,     8,     8,     8,     8,     8,     8,     8,
  /*0x68-0x6F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x70-0x77*/    74,    74,    86,    86,    86,    86,   100,   100,
  /*0x78-0x7F*/   128,   128,   112,   112,   126,   126,     0,     0
};

static const _pSLint32_Type Table_19[128] =
{
  /*0x00-0x07*/     8,     8,     8,     8,     8,     8,     8,     8,
  /*0x08-0x0F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x10-0x17*/     8,     8,     8,     8,     8,     8,     8,     8,
  /*0x18-0x1F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x20-0x27*/     8,     8,     8,     8,     8,     8,     8,     8,
  /*0x28-0x2F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x30-0x37*/     8,     8,     0,     9,     0,     0,     0,     0,
  /*0x38-0x3F*/     0,     0,     0,     0,     0,     0, -7205,     0,
  /*0x40-0x47*/     0,     0,     0,     9,     0,     0,     0,     0,
  /*0x48-0x4F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x50-0x57*/     8,     8,     0,     0,     0,     0,     0,     0,
  /*0x58-0x5F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x60-0x67*/     8,     8,     0,     0,     0,     7,     0,     0,
  /*0x68-0x6F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x70-0x77*/     0,     0,     0,     9,     0,     0,     0,     0,
  /*0x78-0x7F*/     0,     0,     0,     0,     0,     0,     0,     0
};

static const _pSLint32_Type Table_20[128] =
{
  /*0x00-0x07*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x08-0x0F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x10-0x17*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x18-0x1F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x20-0x27*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x28-0x2F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x30-0x37*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x38-0x3F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x40-0x47*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x48-0x4F*/     0,     0,     0,     0,     0,     0,   -28,     0,
  /*0x50-0x57*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x58-0x5F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x60-0x67*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x68-0x6F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x70-0x77*/   -16,   -16,   -16,   -16,   -16,   -16,   -16,   -16,
  /*0x78-0x7F*/   -16,   -16,   -16,   -16,   -16,   -16,   -16,   -16
};

static const _pSLint32_Type Table_21[128] =
{
  /*0x00-0x07*/     0,     0,     0,     0,    -1,     0,     0,     0,
  /*0x08-0x0F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x10-0x17*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x18-0x1F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x20-0x27*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x28-0x2F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x30-0x37*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x38-0x3F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x40-0x47*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x48-0x4F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x50-0x57*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x58-0x5F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x60-0x67*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x68-0x6F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x70-0x77*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x78-0x7F*/     0,     0,     0,     0,     0,     0,     0,     0
};

static const _pSLint32_Type Table_22[128] =
{
  /*0x00-0x07*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x08-0x0F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x10-0x17*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x18-0x1F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x20-0x27*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x28-0x2F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x30-0x37*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x38-0x3F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x40-0x47*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x48-0x4F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x50-0x57*/   -26,   -26,   -26,   -26,   -26,   -26,   -26,   -26,
  /*0x58-0x5F*/   -26,   -26,   -26,   -26,   -26,   -26,   -26,   -26,
  /*0x60-0x67*/   -26,   -26,   -26,   -26,   -26,   -26,   -26,   -26,
  /*0x68-0x6F*/   -26,   -26,     0,     0,     0,     0,     0,     0,
  /*0x70-0x77*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x78-0x7F*/     0,     0,     0,     0,     0,     0,     0,     0
};

static const _pSLint32_Type Table_23[128] =
{
  /*0x00-0x07*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x08-0x0F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x10-0x17*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x18-0x1F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x20-0x27*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x28-0x2F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x30-0x37*/   -48,   -48,   -48,   -48,   -48,   -48,   -48,   -48,
  /*0x38-0x3F*/   -48,   -48,   -48,   -48,   -48,   -48,   -48,   -48,
  /*0x40-0x47*/   -48,   -48,   -48,   -48,   -48,   -48,   -48,   -48,
  /*0x48-0x4F*/   -48,   -48,   -48,   -48,   -48,   -48,   -48,   -48,
  /*0x50-0x57*/   -48,   -48,   -48,   -48,   -48,   -48,   -48,   -48,
  /*0x58-0x5F*/   -48,   -48,   -48,   -48,   -48,   -48,   -48,     0,
  /*0x60-0x67*/     0,    -1,     0,     0,     0, -10795, -10792,     0,
  /*0x68-0x6F*/    -1,     0,    -1,     0,    -1,     0,     0,     0,
  /*0x70-0x77*/     0,     0,     0,    -1,     0,     0,    -1,     0,
  /*0x78-0x7F*/     0,     0,     0,     0,     0,     0,     0,     0
};

static const _pSLint32_Type Table_24[128] =
{
  /*0x00-0x07*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x08-0x0F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x10-0x17*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x18-0x1F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x20-0x27*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x28-0x2F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x30-0x37*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x38-0x3F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x40-0x47*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x48-0x4F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x50-0x57*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x58-0x5F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x60-0x67*/     0,    -1,     0,    -1,     0,     0,     0,     0,
  /*0x68-0x6F*/     0,     0,     0,     0,    -1,     0,    -1,     0,
  /*0x70-0x77*/     0,     0,     0,    -1,     0,     0,     0,     0,
  /*0x78-0x7F*/     0,     0,     0,     0,     0,     0,     0,     0
};

static const _pSLint32_Type Table_25[128] =
{
  /*0x00-0x07*/ -7264, -7264, -7264, -7264, -7264, -7264, -7264, -7264,
  /*0x08-0x0F*/ -7264, -7264, -7264, -7264, -7264, -7264, -7264, -7264,
  /*0x10-0x17*/ -7264, -7264, -7264, -7264, -7264, -7264, -7264, -7264,
  /*0x18-0x1F*/ -7264, -7264, -7264, -7264, -7264, -7264, -7264, -7264,
  /*0x20-0x27*/ -7264, -7264, -7264, -7264, -7264, -7264,     0, -7264,
  /*0x28-0x2F*/     0,     0,     0,     0,     0, -7264,     0,     0,
  /*0x30-0x37*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x38-0x3F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x40-0x47*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x48-0x4F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x50-0x57*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x58-0x5F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x60-0x67*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x68-0x6F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x70-0x77*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x78-0x7F*/     0,     0,     0,     0,     0,     0,     0,     0
};

static const _pSLint32_Type Table_26[128] =
{
  /*0x00-0x07*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x08-0x0F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x10-0x17*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x18-0x1F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x20-0x27*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x28-0x2F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x30-0x37*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x38-0x3F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x40-0x47*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x48-0x4F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x50-0x57*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x58-0x5F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x60-0x67*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x68-0x6F*/     0,    -1,     0,    -1,     0,    -1,     0,     0,
  /*0x70-0x77*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x78-0x7F*/     0,     0,     0,     0,     0,     0,     0,     0
};

static const _pSLint32_Type Table_27[128] =
{
  /*0x00-0x07*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x08-0x0F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x10-0x17*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x18-0x1F*/     0,    -1,     0,    -1,     0,     0,     0,     0,
  /*0x20-0x27*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x28-0x2F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x30-0x37*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x38-0x3F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x40-0x47*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x48-0x4F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x50-0x57*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x58-0x5F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x60-0x67*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x68-0x6F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x70-0x77*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x78-0x7F*/     0,     0,     0,     0,     0,     0,     0,     0
};

static const _pSLint32_Type Table_28[128] =
{
  /*0x00-0x07*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x08-0x0F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x10-0x17*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x18-0x1F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x20-0x27*/     0,     0,     0,    -1,     0,    -1,     0,    -1,
  /*0x28-0x2F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x30-0x37*/     0,     0,     0,    -1,     0,    -1,     0,    -1,
  /*0x38-0x3F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x40-0x47*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x48-0x4F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x50-0x57*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x58-0x5F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x60-0x67*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x68-0x6F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x70-0x77*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x78-0x7F*/     0,     0,    -1,     0,    -1,     0,     0,    -1
};

static const _pSLint32_Type Table_29[128] =
{
  /*0x00-0x07*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x08-0x0F*/     0,     0,     0,     0,    -1,     0,     0,     0,
  /*0x10-0x17*/     0,    -1,     0,    -1,     0,     0,     0,    -1,
  /*0x18-0x1F*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x20-0x27*/     0,    -1,     0,    -1,     0,    -1,     0,    -1,
  /*0x28-0x2F*/     0,    -1,     0,     0,     0,     0,     0,     0,
  /*0x30-0x37*/     0,     0,     0,     0,     0,    -1,     0,    -1,
  /*0x38-0x3F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x40-0x47*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x48-0x4F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x50-0x57*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x58-0x5F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x60-0x67*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x68-0x6F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x70-0x77*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x78-0x7F*/     0,     0,     0,     0,     0,     0,     0,     0
};

static const _pSLint32_Type Table_30[128] =
{
  /*0x00-0x07*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x08-0x0F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x10-0x17*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x18-0x1F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x20-0x27*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x28-0x2F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x30-0x37*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x38-0x3F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x40-0x47*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x48-0x4F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x50-0x57*/     0,     0,     0,  -928,     0,     0,     0,     0,
  /*0x58-0x5F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x60-0x67*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x68-0x6F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x70-0x77*/ -38864, -38864, -38864, -38864, -38864, -38864, -38864, -38864,
  /*0x78-0x7F*/ -38864, -38864, -38864, -38864, -38864, -38864, -38864, -38864
};

static const _pSLint32_Type Table_31[128] =
{
  /*0x00-0x07*/ -38864, -38864, -38864, -38864, -38864, -38864, -38864, -38864,
  /*0x08-0x0F*/ -38864, -38864, -38864, -38864, -38864, -38864, -38864, -38864,
  /*0x10-0x17*/ -38864, -38864, -38864, -38864, -38864, -38864, -38864, -38864,
  /*0x18-0x1F*/ -38864, -38864, -38864, -38864, -38864, -38864, -38864, -38864,
  /*0x20-0x27*/ -38864, -38864, -38864, -38864, -38864, -38864, -38864, -38864,
  /*0x28-0x2F*/ -38864, -38864, -38864, -38864, -38864, -38864, -38864, -38864,
  /*0x30-0x37*/ -38864, -38864, -38864, -38864, -38864, -38864, -38864, -38864,
  /*0x38-0x3F*/ -38864, -38864, -38864, -38864, -38864, -38864, -38864, -38864,
  /*0x40-0x47*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x48-0x4F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x50-0x57*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x58-0x5F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x60-0x67*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x68-0x6F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x70-0x77*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x78-0x7F*/     0,     0,     0,     0,     0,     0,     0,     0
};

static const _pSLint32_Type Table_32[128] =
{
  /*0x00-0x07*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x08-0x0F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x10-0x17*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x18-0x1F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x20-0x27*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x28-0x2F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x30-0x37*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x38-0x3F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x40-0x47*/     0,   -32,   -32,   -32,   -32,   -32,   -32,   -32,
  /*0x48-0x4F*/   -32,   -32,   -32,   -32,   -32,   -32,   -32,   -32,
  /*0x50-0x57*/   -32,   -32,   -32,   -32,   -32,   -32,   -32,   -32,
  /*0x58-0x5F*/   -32,   -32,   -32,     0,     0,     0,     0,     0,
  /*0x60-0x67*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x68-0x6F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x70-0x77*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x78-0x7F*/     0,     0,     0,     0,     0,     0,     0,     0
};

static const _pSLint32_Type Table_33[128] =
{
  /*0x00-0x07*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x08-0x0F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x10-0x17*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x18-0x1F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x20-0x27*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x28-0x2F*/   -40,   -40,   -40,   -40,   -40,   -40,   -40,   -40,
  /*0x30-0x37*/   -40,   -40,   -40,   -40,   -40,   -40,   -40,   -40,
  /*0x38-0x3F*/   -40,   -40,   -40,   -40,   -40,   -40,   -40,   -40,
  /*0x40-0x47*/   -40,   -40,   -40,   -40,   -40,   -40,   -40,   -40,
  /*0x48-0x4F*/   -40,   -40,   -40,   -40,   -40,   -40,   -40,   -40,
  /*0x50-0x57*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x58-0x5F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x60-0x67*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x68-0x6F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x70-0x77*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x78-0x7F*/     0,     0,     0,     0,     0,     0,     0,     0
};

static const _pSLint32_Type Table_34[128] =
{
  /*0x00-0x07*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x08-0x0F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x10-0x17*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x18-0x1F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x20-0x27*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x28-0x2F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x30-0x37*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x38-0x3F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x40-0x47*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x48-0x4F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x50-0x57*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x58-0x5F*/   -40,   -40,   -40,   -40,   -40,   -40,   -40,   -40,
  /*0x60-0x67*/   -40,   -40,   -40,   -40,   -40,   -40,   -40,   -40,
  /*0x68-0x6F*/   -40,   -40,   -40,   -40,   -40,   -40,   -40,   -40,
  /*0x70-0x77*/   -40,   -40,   -40,   -40,   -40,   -40,   -40,   -40,
  /*0x78-0x7F*/   -40,   -40,   -40,   -40,     0,     0,     0,     0
};

static const _pSLint32_Type Table_35[128] =
{
  /*0x00-0x07*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x08-0x0F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x10-0x17*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x18-0x1F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x20-0x27*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x28-0x2F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x30-0x37*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x38-0x3F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x40-0x47*/   -64,   -64,   -64,   -64,   -64,   -64,   -64,   -64,
  /*0x48-0x4F*/   -64,   -64,   -64,   -64,   -64,   -64,   -64,   -64,
  /*0x50-0x57*/   -64,   -64,   -64,   -64,   -64,   -64,   -64,   -64,
  /*0x58-0x5F*/   -64,   -64,   -64,   -64,   -64,   -64,   -64,   -64,
  /*0x60-0x67*/   -64,   -64,   -64,   -64,   -64,   -64,   -64,   -64,
  /*0x68-0x6F*/   -64,   -64,   -64,   -64,   -64,   -64,   -64,   -64,
  /*0x70-0x77*/   -64,   -64,   -64,     0,     0,     0,     0,     0,
  /*0x78-0x7F*/     0,     0,     0,     0,     0,     0,     0,     0
};

static const _pSLint32_Type Table_36[128] =
{
  /*0x00-0x07*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x08-0x0F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x10-0x17*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x18-0x1F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x20-0x27*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x28-0x2F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x30-0x37*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x38-0x3F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x40-0x47*/   -32,   -32,   -32,   -32,   -32,   -32,   -32,   -32,
  /*0x48-0x4F*/   -32,   -32,   -32,   -32,   -32,   -32,   -32,   -32,
  /*0x50-0x57*/   -32,   -32,   -32,   -32,   -32,   -32,   -32,   -32,
  /*0x58-0x5F*/   -32,   -32,   -32,   -32,   -32,   -32,   -32,   -32,
  /*0x60-0x67*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x68-0x6F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x70-0x77*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x78-0x7F*/     0,     0,     0,     0,     0,     0,     0,     0
};

static const _pSLint32_Type Table_37[128] =
{
  /*0x00-0x07*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x08-0x0F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x10-0x17*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x18-0x1F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x20-0x27*/     0,     0,   -34,   -34,   -34,   -34,   -34,   -34,
  /*0x28-0x2F*/   -34,   -34,   -34,   -34,   -34,   -34,   -34,   -34,
  /*0x30-0x37*/   -34,   -34,   -34,   -34,   -34,   -34,   -34,   -34,
  /*0x38-0x3F*/   -34,   -34,   -34,   -34,   -34,   -34,   -34,   -34,
  /*0x40-0x47*/   -34,   -34,   -34,   -34,     0,     0,     0,     0,
  /*0x48-0x4F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x50-0x57*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x58-0x5F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x60-0x67*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x68-0x6F*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x70-0x77*/     0,     0,     0,     0,     0,     0,     0,     0,
  /*0x78-0x7F*/     0,     0,     0,     0,     0,     0,     0,     0
};

const _pSLint32_Type *_pSLwc_Toupper_Table[979] =
{
  Table_01,  Table_02,  Table_03,  Table_04,  Table_05,  Table_06,
  Table_07,  Table_08,  Table_09,  Table_10,  Table_11,  Table_12,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_13,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_14,  Table_15,  Table_00,
  Table_16,  Table_17,  Table_18,  Table_19,  Table_00,  Table_00,
  Table_20,  Table_21,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_22,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_23,  Table_24,
  Table_25,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_26,  Table_27,  Table_28,  Table_29,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_30,  Table_31,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_32,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_33,  Table_34,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_35,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_36,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,  Table_00,
  Table_37
};
#endif /* DEFINE_PSLWC_TOUPPER_TABLE */
